@@ -18,29 +18,20 @@ def main():
     p = ArgumentParser()
     p.add_argument("ref", help="filename to compare against")
     p.add_argument("root", help="top-level directory to search under")
-    p.add_argument("-l", "--language", help="language to template")
-    p.add_argument("-exe", help="program to compare with", default="meld")
-    p.add_argument("-s", "--strict", help="compare only with first language match", action="store_true")
+    p.add_argument("-exe", help="program to compare with")
     p.add_argument("-n", "--dryrun", help="just report files that are different", action="store_true")
     p = p.parse_args()
 
-    if p.dryrun:
-        level = logging.INFO
-    else:
-        level = logging.WARNING
+    level = logging.INFO if p.dryrun else None
     logging.basicConfig(format="%(message)s", level=level)
 
-    root = Path(p.root).expanduser()
-    if not root.is_dir():
-        raise SystemExit(f"{root} is not a directory")
+    ref = Path(p.ref).expanduser().resolve()
 
-    files = mu.files_to_meld(root, p.ref, p.language, strict=p.strict)
-
-    for file in files:
+    for file in mu.files_to_diff(p.root, ref):
         if p.dryrun:
-            print(f"{file}  !=  {p.ref}")
+            print(file, "!=", ref)
         else:
-            mu.meld_files(p.ref, file, p.exe)
+            mu.diff_gui(p.ref, file, p.exe)
 
 
 if __name__ == "__main__":
